{
    "$graph": [
        {
            "class": "CommandLineTool",
            "doc": "GATK-SelectVariants.cwl is developed for CWL consortium\n\nUsage:\n```\njava -Xmx8G \\\n      -jar gatk.jar\n      -T SelectVariants \\\n      -R reference.fa \\\n      -V raw_HC_variants.vcf \\\n      -selectType INDEL \\\n      -o raw_indels.vcf\n```\n",
            "hints": [
                {
                    "class": "EnvVarRequirement",
                    "envDef": [
                        {
                            "envName": "PATH",
                            "envValue": "/usr/local/bin/:/usr/bin:/bin"
                        }
                    ],
                    "id": "#envvar-global.yml"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "scidap/gatk:v3.5",
                    "dockerFile": "#################################################################\n# Dockerfile\n#\n# Software:         GATK\n# Software Version: 3.5\n# Description:      GATK image for SciDAP\n# Website:          http://scidap.com/\n# Provides:         GATK|bwa|picard\n\n# Base Image:       scidap/scidap:v0.0.1\n#################################################################\n\n### Base Image\nFROM scidap/scidap:v0.0.1\nMAINTAINER Andrey V Kartashov \"porter@porter.st\"\nENV DEBIAN_FRONTEND noninteractive\n\n################## BEGIN INSTALLATION ######################\n\nWORKDIR /tmp\n\n### Install required packages (samtools)\n\nRUN apt-get clean all &&\\\n    apt-get update &&\\\n    apt-get install -y --no-install-recommends \\\n        libncurses5-dev \\\n        bzip2 \\\n        zlib1g-dev \\\n        libncursesw5-dev \\\n        openjdk-7-jdk \\\n        maven && \\\n    apt-get clean && \\\n    apt-get purge && \\\n    rm -rf /var/lib/apt/lists/* /tmp/* /var/tmp/* /usr/share/doc/*\n\n\n### Installing BWA\n\nENV VERSION 0.7.12\nENV NAME bwa\nENV URL \"https://github.com/lh3/bwa/archive/${VERSION}.tar.gz\"\n\nRUN wget -q -O - $URL | tar -zxv && \\\n    cd ${NAME}-${VERSION} && \\\n    make -j 4 && \\\n    cd .. && \\\n    cp ./${NAME}-${VERSION}/${NAME} /usr/local/bin/ && \\\n    strip /usr/local/bin/${NAME}; true && \\\n    rm -rf ./${NAME}-${VERSION}/\n\n\n### Installing samtools/htslib/tabix/bgzip\n\nENV VERSIONH 1.2.1\nENV NAMEH htslib\nENV URLH \"https://github.com/samtools/htslib/archive/${VERSIONH}.tar.gz\"\n\nENV VERSION \"1.2\"\nENV NAME \"samtools\"\nENV URL \"https://github.com/samtools/samtools/archive/${VERSION}.tar.gz\"\n\nRUN wget -q -O - $URLH | tar -zxv && \\\n    cd ${NAMEH}-${VERSIONH} && \\\n    make -j 4 && \\\n    cd .. && \\\n    cp ./${NAMEH}-${VERSIONH}/tabix /usr/local/bin/ && \\\n    cp ./${NAMEH}-${VERSIONH}/bgzip /usr/local/bin/ && \\\n    cp ./${NAMEH}-${VERSIONH}/htsfile /usr/local/bin/ && \\\n    strip /usr/local/bin/tabix; true && \\\n    strip /usr/local/bin/bgzip; true && \\\n    strip /usr/local/bin/htsfile; true && \\\n    ln -s ./${NAMEH}-${VERSIONH}/ ./${NAMEH} && \\\n    wget -q -O - $URL | tar -zxv && \\\n    cd ${NAME}-${VERSION} && \\\n    make -j 4 && \\\n    cd .. && \\\n    cp ./${NAME}-${VERSION}/${NAME} /usr/local/bin/ && \\\n    strip /usr/local/bin/${NAME}; true && \\\n    rm -rf ./${NAMEH}-${VERSIONH}/ && \\\n    rm -rf ./${NAME}-${VERSION}/\n\n\n\n### INSTALL PICARD\n\nENV VERSION \"1.141\"\nENV NAME \"picard-tools\"\nENV ZIP ${NAME}-${VERSION}.zip\nENV URL https://github.com/broadinstitute/picard/releases/download/${VERSION}/${ZIP}\n\nRUN wget -q $URL -O ${ZIP} && \\\n    unzip $ZIP && \\\n    rm $ZIP && \\\n    cd ${NAME}-${VERSION} && \\\n    mv * /usr/local/bin && \\\n    cd .. && \\\n    bash -c 'echo -e \"#!/bin/bash\\njava -jar /usr/local/bin/picard.jar \\$@\" > /usr/local/bin/picard' && \\\n    chmod +x /usr/local/bin/picard && \\\n    rm -rf ${NAME}-${VERSION}\n\n\n### INSTALL GATK\n",
                    "id": "#GATK-docker.yml"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-jar"
                    },
                    "id": "#GATK-SelectVariants.cwl/gatk_jar"
                },
                {
                    "type": "string",
                    "default": "-Xmx8g",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#GATK-SelectVariants.cwl/java_arg"
                },
                {
                    "type": "string",
                    "default": "-Djava.io.tmpdir=/tmp",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#GATK-SelectVariants.cwl/java_tmp"
                },
                {
                    "type": "string",
                    "default": "selected.indels.vcf",
                    "inputBinding": {
                        "position": 8,
                        "prefix": "-o"
                    },
                    "id": "#GATK-SelectVariants.cwl/output_filename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-V"
                    },
                    "doc": "input vcf File raw variant calls from haplotype caller",
                    "id": "#GATK-SelectVariants.cwl/raw_vcf"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-R"
                    },
                    "doc": "reference genome",
                    "id": "#GATK-SelectVariants.cwl/reference"
                },
                {
                    "type": "string",
                    "default": "INDEL",
                    "inputBinding": {
                        "position": 7,
                        "prefix": "-selectType"
                    },
                    "id": "#GATK-SelectVariants.cwl/select_type"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "SelectVariants",
                    "position": 4,
                    "prefix": "-T"
                }
            ],
            "baseCommand": [
                "java"
            ],
            "id": "#GATK-SelectVariants.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "doc": "the selected variants as a vcf file",
                    "id": "#GATK-SelectVariants.cwl/output_File"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "doc": "GATK-VariantsFiltration.cwl is developed for CWL consortium\n\nUsage:\n```\njava -Xmx8G \\\n      -jar gatk.jar\n      -T VariantFiltration \\\n      -R reference.fa \\\n      -V raw_indels.vcf \\\n      --filterExpression \"QD < 2.0 || FS > 200.0 || ReadPosRankSum < -20.0\" \\\n      --filterName \"my_indel_filter\" \\\n      -o filtered_indels.vcf\n```\n",
            "hints": [
                {
                    "$import": "#envvar-global.yml"
                },
                {
                    "$import": "#GATK-docker.yml"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "default": "QD < 2.0 || FS > 200.0 || ReadPosRankSum < -20.0",
                    "inputBinding": {
                        "position": 7,
                        "prefix": "--filterExpression"
                    },
                    "id": "#GATK-VariantFiltration.cwl/filter_expression"
                },
                {
                    "type": "string",
                    "default": "indel_filter",
                    "inputBinding": {
                        "position": 8,
                        "prefix": "--filterName"
                    },
                    "id": "#GATK-VariantFiltration.cwl/filter_name"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-jar"
                    },
                    "id": "#GATK-VariantFiltration.cwl/gatk_jar"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-V"
                    },
                    "doc": "input vcf File raw indel variant calls from haplotype caller",
                    "id": "#GATK-VariantFiltration.cwl/indels_vcf"
                },
                {
                    "type": "string",
                    "default": "-Xmx8g",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#GATK-VariantFiltration.cwl/java_arg"
                },
                {
                    "type": "string",
                    "default": "-Djava.io.tmpdir=/tmp",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#GATK-VariantFiltration.cwl/java_tmp"
                },
                {
                    "type": "string",
                    "default": "filtered.indels.vcf",
                    "inputBinding": {
                        "position": 9,
                        "prefix": "-o"
                    },
                    "id": "#GATK-VariantFiltration.cwl/output_filename"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-R"
                    },
                    "doc": "reference genome",
                    "id": "#GATK-VariantFiltration.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "doc": "the filtered vcf file",
                    "id": "#GATK-VariantFiltration.cwl/output_File"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "VariantFiltration",
                    "position": 4,
                    "prefix": "-T"
                }
            ],
            "baseCommand": [
                "java"
            ],
            "id": "#GATK-VariantFiltration.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/snpeff:4.3.1m--0",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-csvStats",
                        "position": 3
                    },
                    "id": "#snpEff.cwl/csvStats"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-dataDir",
                        "position": 1
                    },
                    "id": "#snpEff.cwl/data_dir"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 7
                    },
                    "id": "#snpEff.cwl/genome"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 9
                    },
                    "id": "#snpEff.cwl/java_mem_opts"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-noStats",
                        "position": 2
                    },
                    "id": "#snpEff.cwl/no_stats"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-nodownload",
                        "position": 5
                    },
                    "id": "#snpEff.cwl/nodownload"
                },
                {
                    "type": {
                        "type": "enum",
                        "symbols": [
                            "#snpEff.cwl/output_format/vcf",
                            "#snpEff.cwl/output_format/gatk",
                            "#snpEff.cwl/output_format/bed",
                            "#snpEff.cwl/output_format/bedAnn"
                        ]
                    },
                    "default": "vcf",
                    "inputBinding": {
                        "prefix": "-o",
                        "position": 4
                    },
                    "id": "#snpEff.cwl/output_format"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 8
                    },
                    "id": "#snpEff.cwl/variant_calling_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-v",
                        "position": 6
                    },
                    "id": "#snpEff.cwl/verbose"
                }
            ],
            "stdout": "$(inputs.variant_calling_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '.ann.vcf')",
            "outputs": [
                {
                    "type": "File",
                    "id": "#snpEff.cwl/annotated_vcf",
                    "outputBinding": {
                        "glob": "$(inputs.variant_calling_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '.ann.vcf')"
                    }
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "snpEff_summary.html"
                    },
                    "id": "#snpEff.cwl/summary_html"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "snpEff_genes.txt"
                    },
                    "id": "#snpEff.cwl/summary_txt"
                }
            ],
            "baseCommand": [
                "snpEff"
            ],
            "arguments": [
                "ann",
                "-stats",
                "snpEff_summary.html"
            ],
            "id": "#snpEff.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "default": "QD < 2.0 || FS > 200.0 || ReadPosRankSum < -20.0",
                    "id": "#main/filter_expression"
                },
                {
                    "type": "string",
                    "default": "filtered.indels.vcf",
                    "id": "#main/filter_output_filename"
                },
                {
                    "type": "File",
                    "doc": "Jar executable of the GATK tool",
                    "id": "#main/gatk_jar"
                },
                {
                    "type": "File",
                    "id": "#main/haplotest_vcf"
                },
                {
                    "type": "string",
                    "default": "INDEL",
                    "id": "#main/indel_mode"
                },
                {
                    "type": "File",
                    "doc": "reference human genome file",
                    "id": "#main/reference"
                },
                {
                    "type": "File",
                    "id": "#main/resource_dbsnp"
                },
                {
                    "type": "File",
                    "id": "#main/resource_hapmap"
                },
                {
                    "type": "File",
                    "id": "#main/resource_mills"
                },
                {
                    "type": "File",
                    "id": "#main/resource_omni"
                },
                {
                    "type": "string",
                    "default": "selected.indels.vcf",
                    "id": "#main/select_output_filename"
                },
                {
                    "type": "string",
                    "default": "SNP",
                    "id": "#main/snp_mode"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "id": "#main/snpeff_java_mem_opts"
                },
                {
                    "type": "Directory",
                    "id": "#main/snpf_data_dir"
                },
                {
                    "type": "string",
                    "id": "#main/snpf_genome"
                },
                {
                    "type": "boolean",
                    "id": "#main/snpf_nodownload"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/snpeff_indels/annotated_vcf",
                    "id": "#main/annotated_indels"
                }
            ],
            "steps": [
                {
                    "run": "#GATK-VariantFiltration.cwl",
                    "in": [
                        {
                            "source": "#main/filter_expression",
                            "id": "#main/filter_indels/filter_expression"
                        },
                        {
                            "source": "#main/gatk_jar",
                            "id": "#main/filter_indels/gatk_jar"
                        },
                        {
                            "source": "#main/select_indels/output_File",
                            "id": "#main/filter_indels/indels_vcf"
                        },
                        {
                            "source": "#main/filter_output_filename",
                            "id": "#main/filter_indels/output_filename"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/filter_indels/reference"
                        }
                    ],
                    "out": [
                        "#main/filter_indels/output_File"
                    ],
                    "id": "#main/filter_indels"
                },
                {
                    "run": "#GATK-SelectVariants.cwl",
                    "in": [
                        {
                            "source": "#main/gatk_jar",
                            "id": "#main/select_indels/gatk_jar"
                        },
                        {
                            "source": "#main/select_output_filename",
                            "id": "#main/select_indels/output_filename"
                        },
                        {
                            "source": "#main/haplotest_vcf",
                            "id": "#main/select_indels/raw_vcf"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/select_indels/reference"
                        },
                        {
                            "source": "#main/indel_mode",
                            "id": "#main/select_indels/select_type"
                        }
                    ],
                    "out": [
                        "#main/select_indels/output_File"
                    ],
                    "id": "#main/select_indels"
                },
                {
                    "run": "#snpEff.cwl",
                    "in": [
                        {
                            "source": "#main/snpf_data_dir",
                            "id": "#main/snpeff_indels/data_dir"
                        },
                        {
                            "source": "#main/snpf_genome",
                            "id": "#main/snpeff_indels/genome"
                        },
                        {
                            "source": "#main/snpeff_java_mem_opts",
                            "id": "#main/snpeff_indels/java_mem_opts"
                        },
                        {
                            "source": "#main/snpf_nodownload",
                            "id": "#main/snpeff_indels/nodownload"
                        },
                        {
                            "source": "#main/filter_indels/output_File",
                            "id": "#main/snpeff_indels/variant_calling_file"
                        }
                    ],
                    "out": [
                        "#main/snpeff_indels/annotated_vcf"
                    ],
                    "id": "#main/snpeff_indels"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
